<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Notification\Domain\Model;

use Centreon\Domain\Common\Assertion\Assertion;

class TimePeriod
{
    public const ALL_TIME_PERIOD = '24x7';

    /**
     * @param int $id
     * @param string $name
     *
     * @throws \Assert\AssertionFailedException
     */
    public function __construct(
        private readonly int $id,
        private readonly string $name,
    ) {
        Assertion::positiveInt($id, 'timePeriod::id');
    }

    /**
     * Get the time period id.
     *
     * @return int
     */
    public function getId(): int
    {
        return $this->id;
    }

    /**
     * Get the time period name.
     *
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }
}
